# vabbat

[![Build Status](https://travis-ci.org/Madoshakalaka/vabbat.svg)](https://travis-ci.org/Madoshakalaka/vabbat)
[![codecov](https://codecov.io/gh/Madoshakalaka/vabbat/branch/master/graph/badge.svg)](https://codecov.io/gh/Madoshakalaka/vabbat)
[![PyPI version](https://badge.fury.io/py/vabbat.svg)](https://badge.fury.io/py/vabbat)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/vabbat.svg)](https://pypi.python.org/pypi/vabbat/)


## Installation

`pip install vabbat`

## What Does It Do

<!--You picture won't show on pypi if you use relative path.-->
<!--If you want to add any image, please add the image to readme_assets folder and add the filename as below-->
<!--![some show case picture](https://raw.githubusercontent.com/Madoshakalaka/vabbat/master/readme_assets/showcasePicture.png)-->
Video Abstraction By Bounding Box And Trajectory


## How to Use


Pip creates command line executable entry point by default

You should be able to run shell command `$ vabbat` anywhere.

- `$ vabbat -h` for more help

- `$ vabbat -h` for more help

in case the command does not work (e.g. on windows when <python_dir>/Scripts is not in system path). Use the package entry:

`> python -m vabbat`
